Graphs
======

Graphs are scraping pipelines aimed at solving specific tasks. They are composed by nodes which can be configured individually to address different aspects of the task (fetching data, extracting information, etc.).

.. toctree::
   :maxdepth: 4

   types
   llm
   graph_config
   benchmarks
   telemetry
